@@ -12,6 +12,10 @@
 #include <memory>
 
 // Qt includes
+#include <QtGlobal>
+#if QT_VERSION >= QT_VERSION_CHECK(6,0,0)
+#include <QtSystemDetection>
+#endif
 #include <QApplication>
 #include <QDir>
 #include <QEvent>
@@ -23,9 +27,8 @@
 #include <utility>
 
 // MythTV includes
-#include <libmyth/mythcontext.h>
-#include <libmyth/mythmediamonitor.h>
 #include <libmythbase/lcddevice.h>
+#include <libmythbase/mythcorecontext.h>
 #include <libmythbase/mythdate.h>
 #include <libmythbase/mythdb.h>
 #include <libmythbase/mythdirs.h>
@@ -34,6 +37,7 @@
 #include <libmythbase/remotefile.h>
 #include <libmythbase/storagegroup.h>
 #include <libmythmetadata/musicutils.h>
+#include <libmythui/mediamonitor.h>
 #include <libmythui/mythdialogbox.h>
 #include <libmythui/mythprogressdialog.h>
 #include <libmythui/mythscreenstack.h>
@@ -67,31 +71,31 @@
 #endif // CD_FRAMESIZE_RAW
 #endif // HAVE_CDIO
 
-QEvent::Type RipStatusEvent::kTrackTextEvent =
+const QEvent::Type RipStatusEvent::kTrackTextEvent =
     (QEvent::Type) QEvent::registerEventType();
-QEvent::Type RipStatusEvent::kOverallTextEvent =
+const QEvent::Type RipStatusEvent::kOverallTextEvent =
     (QEvent::Type) QEvent::registerEventType();
-QEvent::Type RipStatusEvent::kStatusTextEvent =
+const QEvent::Type RipStatusEvent::kStatusTextEvent =
     (QEvent::Type) QEvent::registerEventType();
-QEvent::Type RipStatusEvent::kTrackProgressEvent =
+const QEvent::Type RipStatusEvent::kTrackProgressEvent =
     (QEvent::Type) QEvent::registerEventType();
-QEvent::Type RipStatusEvent::kTrackPercentEvent =
+const QEvent::Type RipStatusEvent::kTrackPercentEvent =
     (QEvent::Type) QEvent::registerEventType();
-QEvent::Type RipStatusEvent::kTrackStartEvent =
+const QEvent::Type RipStatusEvent::kTrackStartEvent =
     (QEvent::Type) QEvent::registerEventType();
-QEvent::Type RipStatusEvent::kOverallProgressEvent =
+const QEvent::Type RipStatusEvent::kOverallProgressEvent =
     (QEvent::Type) QEvent::registerEventType();
-QEvent::Type RipStatusEvent::kOverallPercentEvent =
+const QEvent::Type RipStatusEvent::kOverallPercentEvent =
     (QEvent::Type) QEvent::registerEventType();
-QEvent::Type RipStatusEvent::kOverallStartEvent =
+const QEvent::Type RipStatusEvent::kOverallStartEvent =
     (QEvent::Type) QEvent::registerEventType();
-QEvent::Type RipStatusEvent::kCopyStartEvent =
+const QEvent::Type RipStatusEvent::kCopyStartEvent =
     (QEvent::Type) QEvent::registerEventType();
-QEvent::Type RipStatusEvent::kCopyEndEvent =
+const QEvent::Type RipStatusEvent::kCopyEndEvent =
     (QEvent::Type) QEvent::registerEventType();
-QEvent::Type RipStatusEvent::kFinishedEvent =
+const QEvent::Type RipStatusEvent::kFinishedEvent =
     (QEvent::Type) QEvent::registerEventType();
-QEvent::Type RipStatusEvent::kEncoderErrorEvent =
+const QEvent::Type RipStatusEvent::kEncoderErrorEvent =
     (QEvent::Type) QEvent::registerEventType();
 
 void CDScannerThread::run()
@@ -112,7 +116,8 @@ void CDEjectorThread::run()
 
 ///////////////////////////////////////////////////////////////////////////////
 
-static long int getSectorCount (QString &cddevice, int tracknum)
+static long int getSectorCount ([[maybe_unused]] QString &cddevice,
+                                [[maybe_unused]] int tracknum)
 {
 #ifdef HAVE_CDIO
     QByteArray devname = cddevice.toLatin1();
@@ -148,8 +153,6 @@ static long int getSectorCount (QString &cddevice, int tracknum)
         QString("Error: cdrip - cdda_track_audiop(%1) returned 0").arg(cddevice));
 
     cdda_close(device);
-#else
-    (void)cddevice; (void)tracknum;
 #endif // HAVE_CDIO
     return 0;
 }
@@ -167,10 +170,10 @@ CDRipperThread::CDRipperThread(RipStatus *parent,  QString device,
     m_cdDevice(std::move(device)), m_quality(quality),
     m_tracks(tracks)
 {
-#ifdef WIN32 // libcdio needs the drive letter with no path
+#ifdef Q_OS_WINDOWS // libcdio needs the drive letter with no path
     if (m_cdDevice.endsWith('\\'))
         m_cdDevice.chop(1);
-#endif // WIN32
+#endif // Q_OS_WINDOWS
 
     QString lastHost = gCoreContext->GetSetting("MythMusicLastRipHost", gCoreContext->GetMasterHostName());
     QStringList dirs = StorageGroup::getGroupDirs("Music", lastHost);
@@ -208,6 +211,8 @@ void CDRipperThread::run(void)
     m_totalSectorsDone = 0;
     for (int trackno = 0; trackno < m_tracks->size(); trackno++)
     {
+        if (!m_tracks->at(trackno)->active)
+            continue;
         m_totalSectors += getSectorCount(m_cdDevice, trackno + 1);
     }
 
@@ -293,46 +298,46 @@ void CDRipperThread::run(void)
                 new RipStatusEvent(RipStatusEvent::kTrackPercentEvent, 0));
 
             // do we need to start a new file?
-            if (m_tracks->at(trackno)->active)
+            if (!m_tracks->at(trackno)->active)
+                continue;
+
+            titleTrack = track;
+            titleTrack->setLength(m_tracks->at(trackno)->length);
+
+            if (m_quality < 3)
             {
-                titleTrack = track;
-                titleTrack->setLength(m_tracks->at(trackno)->length);
-
-                if (m_quality < 3)
+                if (encodertype == "mp3")
                 {
-                    if (encodertype == "mp3")
-                    {
-                        outfile = QString("track%1.mp3").arg(trackno);
-                        encoder = std::make_unique<LameEncoder>(saveDir + outfile, m_quality,
-                                                      titleTrack, mp3usevbr);
-                    }
-                    else // ogg
-                    {
-                        outfile = QString("track%1.ogg").arg(trackno);
-                        encoder = std::make_unique<VorbisEncoder>(saveDir + outfile, m_quality,
-                                                        titleTrack);
-                    }
+                    outfile = QString("track%1.mp3").arg(trackno);
+                    encoder = std::make_unique<LameEncoder>(saveDir + outfile, m_quality,
+                                                  titleTrack, mp3usevbr);
                 }
-                else
+                else // ogg
                 {
-                    outfile = QString("track%1.flac").arg(trackno);
-                    encoder = std::make_unique<FlacEncoder>(saveDir + outfile, m_quality,
-                                                  titleTrack);
+                    outfile = QString("track%1.ogg").arg(trackno);
+                    encoder = std::make_unique<VorbisEncoder>(saveDir + outfile, m_quality,
+                                                    titleTrack);
                 }
+            }
+            else
+            {
+                outfile = QString("track%1.flac").arg(trackno);
+                encoder = std::make_unique<FlacEncoder>(saveDir + outfile, m_quality,
+                                              titleTrack);
+            }
 
-                if (!encoder->isValid())
-                {
-                    QApplication::postEvent(
-                        m_parent,
-                        new RipStatusEvent(
-                            RipStatusEvent::kEncoderErrorEvent,
-                            "Encoder failed to open file for writing"));
-                    LOG(VB_GENERAL, LOG_ERR, "MythMusic: Encoder failed"
-                                             " to open file for writing");
+            if (!encoder->isValid())
+            {
+                QApplication::postEvent(
+                    m_parent,
+                    new RipStatusEvent(
+                        RipStatusEvent::kEncoderErrorEvent,
+                        "Encoder failed to open file for writing"));
+                LOG(VB_GENERAL, LOG_ERR, "MythMusic: Encoder failed"
+                                         " to open file for writing");
 
-                    RunEpilog();
-                    return;
-                }
+                RunEpilog();
+                return;
             }
 
             if (!encoder)
@@ -354,28 +359,25 @@ void CDRipperThread::run(void)
                 return;
             }
 
-            if (m_tracks->at(trackno)->active)
-            {
-                QString ext = QFileInfo(outfile).suffix();
-                QString destFile = filenameFromMetadata(titleTrack) + '.' + ext;
-                QUrl url(m_musicStorageDir);
+            QString ext = QFileInfo(outfile).suffix();
+            QString destFile = filenameFromMetadata(titleTrack) + '.' + ext;
+            QUrl url(m_musicStorageDir);
 
-                // save the metadata to the DB
-                titleTrack->setFilename(destFile);
-                titleTrack->setHostname(url.host());
-                titleTrack->setFileSize((quint64)QFileInfo(outfile).size());
-                titleTrack->dumpToDatabase();
+            // save the metadata to the DB
+            titleTrack->setFilename(destFile);
+            titleTrack->setHostname(url.host());
+            titleTrack->setFileSize((quint64)QFileInfo(outfile).size());
+            titleTrack->dumpToDatabase();
 
-                // this will delete the encoder which will write the metadata in it's dtor
-                encoder.reset();
+            // this will delete the encoder which will write the metadata in it's dtor
+            encoder.reset();
 
-                // copy track to the BE
-                destFile = MythCoreContext::GenMythURL(url.host(), 0, destFile, "Music");
+            // copy track to the BE
+            destFile = MythCoreContext::GenMythURL(url.host(), 0, destFile, "Music");
 
-                QApplication::postEvent(m_parent, new RipStatusEvent(RipStatusEvent::kCopyStartEvent, 0));
-                RemoteFile::CopyFile(saveDir + outfile, destFile, true);
-                QApplication::postEvent(m_parent, new RipStatusEvent(RipStatusEvent::kCopyEndEvent, 0));
-            }
+            QApplication::postEvent(m_parent, new RipStatusEvent(RipStatusEvent::kCopyStartEvent, 0));
+            RemoteFile::CopyFile(saveDir + outfile, destFile, true);
+            QApplication::postEvent(m_parent, new RipStatusEvent(RipStatusEvent::kCopyEndEvent, 0));
         }
     }
 
@@ -390,7 +392,9 @@ void CDRipperThread::run(void)
     RunEpilog();
 }
 
-int CDRipperThread::ripTrack(QString &cddevice, Encoder *encoder, int tracknum)
+int CDRipperThread::ripTrack([[maybe_unused]] QString &cddevice,
+                             [[maybe_unused]] Encoder *encoder,
+                             [[maybe_unused]] int tracknum)
 {
 #ifdef HAVE_CDIO
     QByteArray devname = cddevice.toLatin1();
@@ -508,7 +512,6 @@ int CDRipperThread::ripTrack(QString &cddevice, Encoder *encoder, int tracknum)
 
     return (curpos - start + 1) * CD_FRAMESIZE_RAW;
 #else
-    (void)cddevice; (void)encoder; (void)tracknum;
     return 0;
 #endif // HAVE_CDIO
 }
@@ -520,16 +523,15 @@ Ripper::Ripper(MythScreenStack *parent, QString device) :
     m_tracks(new QVector<RipTrack*>),
     m_cdDevice(std::move(device))
 {
-#ifndef _WIN32
+#ifndef Q_OS_WINDOWS
     // if the MediaMonitor is running stop it
-    m_mediaMonitorActive = false;
     MediaMonitor *mon = MediaMonitor::GetMediaMonitor();
     if (mon && mon->IsActive())
     {
         m_mediaMonitorActive = true;
         mon->StopMonitoring();
     }
-#endif // _WIN32
+#endif // Q_OS_WINDOWS
 
     // make sure the directory where we temporarily save the rips is present
     QDir dir;
@@ -554,7 +556,7 @@ Ripper::~Ripper(void)
 
     delete m_decoder;
 
-#ifndef _WIN32
+#ifndef Q_OS_WINDOWS
     // if the MediaMonitor was active when we started then restart it
     if (m_mediaMonitorActive)
     {
@@ -562,7 +564,7 @@ Ripper::~Ripper(void)
         if (mon)
             mon->StartMonitoring();
     }
-#endif // _WIN32
+#endif // Q_OS_WINDOWS
 
     if (m_somethingwasripped)
         emit ripFinished();
@@ -640,7 +642,7 @@ bool Ripper::keyPressEvent(QKeyEvent *event)
 
     for (int i = 0; i < actions.size() && !handled; i++)
     {
-        QString action = actions[i];
+        const QString& action = actions[i];
         handled = true;
 
         if (action == "EDIT" || action == "INFO") // INFO purely for historical reasons
@@ -764,7 +766,8 @@ void Ripper::ScanFinished()
         m_genreName.clear();
         m_year.clear();
 
-        for (int trackno = 0; trackno < m_decoder->getNumTracks(); trackno++)
+        int max_tracks = m_decoder->getNumTracks();
+        for (int trackno = 0; trackno < max_tracks; trackno++)
         {
             auto *ripTrack = new RipTrack;
 
@@ -802,7 +805,9 @@ void Ripper::ScanFinished()
 
             }
             else
+            {
                 delete ripTrack;
+            }
         }
 
         m_artistEdit->SetText(m_artistName);
@@ -910,7 +915,7 @@ bool Ripper::deleteExistingTrack(RipTrack *track)
 
         // delete file
         // FIXME: RemoteFile::DeleteFile will only work with files on the master BE
-        if (!RemoteFile::DeleteFile(filename))
+        if (RemoteFile::Exists(filename) && !RemoteFile::DeleteFile(filename))
         {
             LOG(VB_GENERAL, LOG_NOTICE, QString("Ripper::deleteExistingTrack() "
                                                 "Could not delete %1")
@@ -945,7 +950,7 @@ void Ripper::artistChanged()
 
     if (!m_tracks->empty())
     {
-        for (const auto *track : qAsConst(*m_tracks))
+        for (const auto *track : std::as_const(*m_tracks))
         {
             MusicMetadata *data = track->metadata;
             if (data)
@@ -974,7 +979,7 @@ void Ripper::albumChanged()
 
     if (!m_tracks->empty())
     {
-        for (const auto *track : qAsConst(*m_tracks))
+        for (const auto *track : std::as_const(*m_tracks))
         {
             MusicMetadata *data = track->metadata;
             if (data)
@@ -991,7 +996,7 @@ void Ripper::genreChanged()
 
     if (!m_tracks->empty())
     {
-        for (const auto *track : qAsConst(*m_tracks))
+        for (const auto *track : std::as_const(*m_tracks))
         {
             MusicMetadata *data = track->metadata;
             if (data)
@@ -1008,7 +1013,7 @@ void Ripper::yearChanged()
 
     if (!m_tracks->empty())
     {
-        for (const auto *track : qAsConst(*m_tracks))
+        for (const auto *track : std::as_const(*m_tracks))
         {
             MusicMetadata *data = track->metadata;
             if (data)
@@ -1026,7 +1031,7 @@ void Ripper::compilationChanged(bool state)
         if (!m_tracks->empty())
         {
             // Update artist MetaData of each track on the ablum...
-            for (const auto *track : qAsConst(*m_tracks))
+            for (const auto *track : std::as_const(*m_tracks))
             {
                 MusicMetadata *data = track->metadata;
                 if (data)
@@ -1045,7 +1050,7 @@ void Ripper::compilationChanged(bool state)
         if (!m_tracks->empty())
         {
             // Update artist MetaData of each track on the album...
-            for (const auto *track : qAsConst(*m_tracks))
+            for (const auto *track : std::as_const(*m_tracks))
             {
                 MusicMetadata *data = track->metadata;
 
@@ -1073,7 +1078,7 @@ void Ripper::switchTitlesAndArtists()
     QString tmp;
     if (!m_tracks->empty())
     {
-        for (const auto *track : qAsConst(*m_tracks))
+        for (const auto *track : std::as_const(*m_tracks))
         {
             MusicMetadata *data = track->metadata;
 
@@ -1109,7 +1114,9 @@ void Ripper::startRipper(void)
         mainStack->AddScreen(statusDialog);
     }
     else
+    {
         delete statusDialog;
+    }
 }
 
 void Ripper::RipComplete(bool result)
@@ -1221,7 +1228,9 @@ void Ripper::updateTrackList(void)
                 item->SetText(MythDate::formatTime(track->length, "mm:ss"), "length");
             }
             else
+            {
                 item->SetText("", "length");
+            }
 
 //             if (i == m_currentTrack)
 //                 m_trackList->SetItemCurrent(i);
@@ -1502,7 +1511,7 @@ bool RipStatus::keyPressEvent(QKeyEvent *event)
 
     for (int i = 0; i < actions.size() && !handled; i++)
     {
-        QString action = actions[i];
+        const QString& action = actions[i];
         handled = true;
 
 
@@ -1515,7 +1524,9 @@ bool RipStatus::keyPressEvent(QKeyEvent *event)
                 dialog->SetReturnEvent(this, "stop_ripping");
         }
         else
+        {
             handled = false;
+        }
     }
 
     if (!handled && MythScreenType::keyPressEvent(event))
